@@ -4,9 +4,9 @@ Main interface for transfer service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_transfer.type_defs import DescribedServerTypeDef
+    from mypy_boto3_transfer.type_defs import DescribedSecurityPolicyTypeDef
 
-    data: DescribedServerTypeDef = {...}
+    data: DescribedSecurityPolicyTypeDef = {...}
     ```
 """
 import sys
@@ -25,6 +25,7 @@ else:
 
 
 __all__ = (
+    "DescribedSecurityPolicyTypeDef",
     "DescribedServerTypeDef",
     "DescribedUserTypeDef",
     "EndpointDetailsTypeDef",
@@ -36,9 +37,11 @@ __all__ = (
     "TagTypeDef",
     "CreateServerResponseTypeDef",
     "CreateUserResponseTypeDef",
+    "DescribeSecurityPolicyResponseTypeDef",
     "DescribeServerResponseTypeDef",
     "DescribeUserResponseTypeDef",
     "ImportSshPublicKeyResponseTypeDef",
+    "ListSecurityPoliciesResponseTypeDef",
     "ListServersResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "ListUsersResponseTypeDef",
@@ -48,6 +51,28 @@ __all__ = (
     "UpdateUserResponseTypeDef",
 )
 
+_RequiredDescribedSecurityPolicyTypeDef = TypedDict(
+    "_RequiredDescribedSecurityPolicyTypeDef", {"SecurityPolicyName": str}
+)
+_OptionalDescribedSecurityPolicyTypeDef = TypedDict(
+    "_OptionalDescribedSecurityPolicyTypeDef",
+    {
+        "Fips": bool,
+        "SshCiphers": List[str],
+        "SshKexs": List[str],
+        "SshMacs": List[str],
+        "TlsCiphers": List[str],
+    },
+    total=False,
+)
+
+
+class DescribedSecurityPolicyTypeDef(
+    _RequiredDescribedSecurityPolicyTypeDef, _OptionalDescribedSecurityPolicyTypeDef
+):
+    pass
+
+
 _RequiredDescribedServerTypeDef = TypedDict("_RequiredDescribedServerTypeDef", {"Arn": str})
 _OptionalDescribedServerTypeDef = TypedDict(
     "_OptionalDescribedServerTypeDef",
@@ -60,6 +85,7 @@ _OptionalDescribedServerTypeDef = TypedDict(
         "IdentityProviderType": Literal["SERVICE_MANAGED", "API_GATEWAY"],
         "LoggingRole": str,
         "Protocols": List[Literal["SFTP", "FTP", "FTPS"]],
+        "SecurityPolicyName": str,
         "ServerId": str,
         "State": Literal[
             "OFFLINE", "ONLINE", "STARTING", "STOPPING", "START_FAILED", "STOP_FAILED"
@@ -162,6 +188,10 @@ CreateUserResponseTypeDef = TypedDict(
     "CreateUserResponseTypeDef", {"ServerId": str, "UserName": str}
 )
 
+DescribeSecurityPolicyResponseTypeDef = TypedDict(
+    "DescribeSecurityPolicyResponseTypeDef", {"SecurityPolicy": "DescribedSecurityPolicyTypeDef"}
+)
+
 DescribeServerResponseTypeDef = TypedDict(
     "DescribeServerResponseTypeDef", {"Server": "DescribedServerTypeDef"}
 )
@@ -174,6 +204,20 @@ ImportSshPublicKeyResponseTypeDef = TypedDict(
     "ImportSshPublicKeyResponseTypeDef", {"ServerId": str, "SshPublicKeyId": str, "UserName": str}
 )
 
+_RequiredListSecurityPoliciesResponseTypeDef = TypedDict(
+    "_RequiredListSecurityPoliciesResponseTypeDef", {"SecurityPolicyNames": List[str]}
+)
+_OptionalListSecurityPoliciesResponseTypeDef = TypedDict(
+    "_OptionalListSecurityPoliciesResponseTypeDef", {"NextToken": str}, total=False
+)
+
+
+class ListSecurityPoliciesResponseTypeDef(
+    _RequiredListSecurityPoliciesResponseTypeDef, _OptionalListSecurityPoliciesResponseTypeDef
+):
+    pass
+
+
 _RequiredListServersResponseTypeDef = TypedDict(
     "_RequiredListServersResponseTypeDef", {"Servers": List["ListedServerTypeDef"]}
 )
